import { Duration, RemovalPolicy } from 'aws-cdk-lib';
import { EventPattern, IRule } from 'aws-cdk-lib/aws-events';
import { IRole, Role } from 'aws-cdk-lib/aws-iam';
import { IKey, Key } from 'aws-cdk-lib/aws-kms';
import { IFunction } from 'aws-cdk-lib/aws-lambda';
import { ILogGroup, RetentionDays } from 'aws-cdk-lib/aws-logs';
import { IQueue } from 'aws-cdk-lib/aws-sqs';
import { StateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { Construct } from 'constructs';
/**
 * Interface for the authorizer central workflow
 */
export interface AuthorizerCentralWorflow {
    /**
     * The authorizer Step Functions state machine
     */
    readonly stateMachine: StateMachine;
    /**
     * The IAM Role used by the State Machine
     */
    readonly stateMachineRole: Role;
    /**
     * The CloudWatch Log Group for logging the state machine
     */
    readonly stateMachineLogGroup: ILogGroup;
    /**
     * The IAM Role used by the State Machine Call Back
     */
    readonly callbackRole: Role;
    /**
     * The authorizer event rule for triggering the workflow
     */
    readonly authorizerEventRule: IRule;
    /**
     * The authorizer event role for allowing events to invoke the workflow
     */
    readonly authorizerEventRole: IRole;
    /**
     * The SQS Dead Letter Queue receiving events failure
     */
    readonly deadLetterQueue: IQueue;
    /**
     * The KMS Key used for encryption of the Dead Letter Queue
     */
    readonly deadLetterKey: IKey;
}
/**
 * Create the resources used by a central authorizer workflow.
 * @param scope The scope creating the resources
 * @param authorizerName The name of the authorizer
 * @param metadataCollectorFunction The Lambda function collecting metadata from the governance tool
 * @param governanceCallbackFunction The Lambda function acknowledging the grant in the governance tool
 * @param eventPattern The event pattern for triggering the authorizer workflow
 * @param workflowTimeout The timeout for the authorizer workflow. @default - 5 minutes
 * @param retryAttempts The number of retry attempts for the authorizer workflow. @default - No retry
 * @param logRetention The retention period for the created logs. @default - 1 week
 * @param authorizerEventRole The IAM role for the authorizer event rule. @default - A new role will be created
 * @param stateMachineRole The IAM role for the authorizer workflow. @default - A new role will be created
 * @param callbackRole The IAM role for the authorizer callback. @default - A new role will be created
 * @param removalPolicy The removal policy for the created resources. @default - RemovalPolicy.RETAIN
 * @returns The created AuthorizerCentralWorflow
 */
export declare function authorizerCentralWorkflowSetup(scope: Construct, authorizerName: string, metadataCollectorFunction: IFunction, governanceCallbackFunction: IFunction, eventPattern: EventPattern, workflowTimeout?: Duration, retryAttempts?: number, logRetention?: RetentionDays, authorizerEventRole?: Role, stateMachineRole?: Role, callbackRole?: Role, deadLetterQueueKey?: Key, removalPolicy?: RemovalPolicy): AuthorizerCentralWorflow;
/**
 * Register an account into a central authorizer workflow to allow cross account communication.
 * @param scope The scope of created resources
 * @param id The id of the created resources
 * @param accountId The account ID to register with the central authorizer
 * @param role The role to grant access to
 * @returns The CfnEventBusPolicy created to grant the account
 */
export declare function registerAccount(scope: Construct, id: string, accountId: string, authorizerName: string, invokeRole: Role, callbackRole: Role): void;
