import { IRole, PolicyStatement } from 'aws-cdk-lib/aws-iam';
import { IFunction } from 'aws-cdk-lib/aws-lambda';
import { ILogGroup, LogGroup } from 'aws-cdk-lib/aws-logs';
import { IStateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { Construct } from 'constructs';
import { DataZoneMskEnvironmentAuthorizerProps } from './datazone-msk-environment-authorizer-props';
import { TrackedConstruct } from '../../../utils';
/**
 * An environment authorizer workflow for granting read access to Kafka topics.
 * The workflow is triggered by an event sent by the central authorizer construct.
 * It creates IAM policies required for the Kafka client to access the relevant topics.
 * It supports MSK provisioned and serverless, in single and cross accounts, and grant/revoke requests.
 *
 * @example
 * new dsf.governance.DataZoneMskEnvironmentAuthorizer(this, 'MskAuthorizer', {
 *   domainId: 'aba_dc999t9ime9sss',
 * });
 */
export declare class DataZoneMskEnvironmentAuthorizer extends TrackedConstruct {
    static readonly PERMISSIONS_BOUNDARY_STATEMENTS: PolicyStatement;
    private static readonly DEFAULT_LOGS_RETENTION;
    /**
     * The IAM role used to grant access to Kafka topics
     */
    readonly grantRole: IRole;
    /**
     * The lambda function used to grant access to Kafka topics
     */
    readonly grantFunction: IFunction;
    /**
     * The IAM role used by the environment authorizer State Machine
     */
    readonly stateMachineRole: IRole;
    /**
     * The CloudWatch Log Group used by the Step Functions state machine
     */
    readonly stateMachineLogGroup: ILogGroup;
    /**
     * The environment authorizer State Machine
     */
    readonly stateMachine: IStateMachine;
    /**
     * The CloudWatch Log Group used by the grant function
     */
    readonly grantLogGroup: LogGroup;
    private readonly removalPolicy;
    /**
     * Create an instance of the DataZoneMskEnvironmentAuthorizer construct
     * @param scope The CDK Construct scope
     * @param id The CDK Construct id
     * @param props The props for the DataZoneMskEnvironmentAuthorizer construct
     */
    constructor(scope: Construct, id: string, props: DataZoneMskEnvironmentAuthorizerProps);
}
