import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import { IBucket } from 'aws-cdk-lib/aws-s3';
import { CodePipeline } from 'aws-cdk-lib/pipelines';
import { Construct } from 'constructs';
import { SparkEmrCICDPipelineProps } from './spark-emr-cicd-pipeline-props';
import { TrackedConstruct } from '../../../utils';
import { IntegrationTestStack } from '../../../utils/lib/integration-test-stack';
/**
 * A CICD Pipeline to test and deploy a Spark application on Amazon EMR in cross-account environments using CDK Pipelines.
 * @see https://awslabs.github.io/data-solutions-framework-on-aws/docs/constructs/library/Processing/spark-cicd-pipeline
 *
 * @exampleMetadata fixture=imports-only
 * @example
 * import { Bucket } from 'aws-cdk-lib/aws-s3';
 * import { CodePipelineSource } from 'aws-cdk-lib/pipelines';
 *
 * interface MyApplicationStackProps extends cdk.StackProps {
 *   readonly stage: dsf.utils.CICDStage;
 * }
 *
 * class MyApplicationStack extends cdk.Stack {
 *   constructor(scope: cdk.Stack, props?: MyApplicationStackProps) {
 *     super(scope, 'MyApplicationStack');
 *     const bucket = new Bucket(this, 'TestBucket', {
 *       autoDeleteObjects: true,
 *       removalPolicy: cdk.RemovalPolicy.DESTROY,
 *     });
 *     new cdk.CfnOutput(this, 'BucketName', { value: bucket.bucketName });
 *   }
 * }
 *
 * class MyStackFactory implements dsf.utils.ApplicationStackFactory {
 *   createStack(scope: cdk.Stack, stage: dsf.utils.CICDStage): cdk.Stack {
 *     return new MyApplicationStack(scope, { stage });
 *   }
 * }
 *
 * class MyCICDStack extends cdk.Stack {
 *   constructor(scope: Construct, id: string) {
 *     super(scope, id);
 *
 *     new dsf.processing.SparkEmrCICDPipeline(this, 'TestConstruct', {
 *        sparkApplicationName: 'test',
 *        applicationStackFactory: new MyStackFactory(),
 *        cdkApplicationPath: 'cdk/',
 *        sparkApplicationPath: 'spark/',
 *        sparkImage: dsf.processing.SparkImage.EMR_6_12,
 *        integTestScript: 'cdk/integ-test.sh',
 *        integTestEnv: {
 *          TEST_BUCKET: 'BucketName',
 *        },
 *        source: CodePipelineSource.connection('owner/weekly-job', 'mainline', {
 *              connectionArn: 'arn:aws:codeconnections:eu-west-1:123456789012:connection/aEXAMPLE-8aad-4d5d-8878-dfcab0bc441f'
 *        }),
 *   });
 * }
 * }
 */
export declare class SparkEmrCICDPipeline extends TrackedConstruct {
    /**
     * Extract the path and the script name from a script path
     * @param path the script path
     * @return [path, scriptName]
     */
    private static extractPath;
    /**
     * Build the install commands for the CodeBuild step based on the runtime
     * @param cdkPath the path of the CDK application
     * @param sparkPath the path of the Spark application
     * @return installCommands
     */
    private static synthCommands;
    /**
     * The CodePipeline created as part of the Spark CICD Pipeline
     */
    readonly pipeline: CodePipeline;
    /**
     * The S3 Bucket for storing the artifacts
     */
    readonly artifactBucket: IBucket;
    /**
     * The S3 Bucket for storing the access logs on the artifact S3 Bucket
     */
    readonly artifactAccessLogsBucket: IBucket;
    /**
     * The CloudWatch Log Group for storing the CodePipeline logs
     */
    readonly pipelineLogGroup: ILogGroup;
    /**
     * The IntegrationTestStack containing resources for the running the integration tests
     */
    readonly integrationTestStack?: IntegrationTestStack;
    /**
     * Construct a new instance of the SparkCICDPipeline class.
     * @param {Construct} scope the Scope of the CDK Construct
     * @param {string} id the ID of the CDK Construct
     * @param {SparkEmrCICDPipelineProps} props the SparkCICDPipelineProps properties
     */
    constructor(scope: Construct, id: string, props: SparkEmrCICDPipelineProps);
    /**
     * Attaches the given stage to the pipeline
     * @param stageName name of the stage in the CI/CD pipeline
     * @param resourceEnvironment the environment details which AWS account/region to deploy
     * @param attachIntegTest whether the integration test should be attached or not
     * @param props the props of the SparkEmrCICDPipeline construct
     * @returns {IntegrationTestStack|undefined} if integration step is configured, this returns the corresponding stack of the integration test
     */
    private attachStageToPipeline;
    /**
     * Extract PROD and STAGING account IDs and regions from the CDK context
     */
    private getAccountFromContext;
    /**
     * Retrieves the list of user defined environments from the context
     * @returns {CICDEnvironment[]} list of user defined environments
     */
    private getUserDefinedEnvironmentsFromContext;
}
