import { IGatewayVpcEndpoint, ISecurityGroup, IVpc } from 'aws-cdk-lib/aws-ec2';
import { CfnApplication } from 'aws-cdk-lib/aws-emrserverless';
import { PolicyDocument, IRole } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import { Construct } from 'constructs';
import { SparkEmrServerlessRuntimeProps } from './spark-emr-runtime-serverless-props';
import { TrackedConstruct } from '../../../../utils';
/**
 * A construct to create a Spark EMR Serverless Application, along with methods to create IAM roles having the least privilege.
 * @see https://awslabs.github.io/data-solutions-framework-on-aws/docs/constructs/library/Processing/spark-emr-serverless-runtime
 *
 * @example
 * import { Role, AccountRootPrincipal } from 'aws-cdk-lib/aws-iam';
 *
 * const serverlessRuntime = new dsf.processing.SparkEmrServerlessRuntime(this, 'EmrApp', {
 *   name: 'SparkRuntimeServerless',
 * });
 *
 * const executionRole = dsf.processing.SparkEmrServerlessRuntime.createExecutionRole(this, 'ExecutionRole')
 *
 * const submitterRole = new Role (this, 'SubmitterRole', {
 *   assumedBy: new AccountRootPrincipal(),
 * });
 *
 * dsf.processing.SparkEmrServerlessRuntime.grantStartJobExecution(submitterRole, [executionRole.roleArn], ['EMR-serverless-app-ID']);
 */
export declare class SparkEmrServerlessRuntime extends TrackedConstruct {
    /**
     * A static method creating an execution IAM role that can be assumed by EMR Serverless
     * The method returns the role it creates. If no `executionRolePolicyDocument` or `iamPolicyName`
     * The method will return a role with only a trust policy to EMR Servereless service principal.
     * You can use this role then to grant access to any resources you control.
     *
     * @param scope the scope in which to create the role
     * @param id passed to the IAM Role construct object
     * @param executionRolePolicyDocument the inline policy document to attach to the role. These are IAM policies needed by the job.
     * This parameter is mutually execlusive with iamPolicyName.
     * @param iamPolicyName the IAM policy name to attach to the role, this is mutually execlusive with executionRolePolicyDocument
     */
    static createExecutionRole(scope: Construct, id: string, executionRolePolicyDocument?: PolicyDocument, iamPolicyName?: string): IRole;
    /**
     * A static method granting the right to start and monitor a job to an IAM Role.
     * The method will also attach an iam:PassRole permission limited to the IAM Job Execution roles passed
     *
     * @param startJobRole the role that will call the start job api and which needs to have the iam:PassRole permission
     * @param executionRoleArn the role used by EMR Serverless to access resources during the job execution
     * @param applicationArns the EMR Serverless aplication ARN,
     * this is used by the method to limit the EMR Serverless applications the role can submit job to.
     */
    static grantStartJobExecution(startJobRole: IRole, executionRoleArn: string[], applicationArns: string[]): void;
    /**
     * The default CIDR for the VPC when it is created
     */
    private static readonly DEFAULT_CIDR;
    /**
     * The EMR Serverless application
     */
    readonly application: CfnApplication;
    /**
     * If no VPC is provided, one is created by default along with a security group attached to the EMR Serverless Application
     * This attribute is used to expose the security group,
     * if you provide your own security group through the {@link SparkEmrServerlessRuntimeProps} the attribute will be `undefined`
     */
    readonly emrApplicationSecurityGroup?: ISecurityGroup;
    /**
     * The VPC used by the EKS cluster
     */
    readonly vpc?: IVpc;
    /**
     * The KMS Key used for the VPC flow log when the VPC is created
     */
    readonly flowLogKey?: IKey;
    /**
     * The IAM Role used for the VPC flow log when the VPC is created
     */
    readonly flowLogRole?: IRole;
    /**
     * The CloudWatch Log Group for the VPC flow log when the VPC is created
     */
    readonly flowLogGroup?: ILogGroup; /**
     * The S3 VPC endpoint attached to the private subnets of the VPC when VPC is created
     */
    readonly s3VpcEndpoint?: IGatewayVpcEndpoint;
    /**
     * @param {Construct} scope the Scope of the CDK Construct
     * @param {string} id the ID of the CDK Construct
     * @param props {@link SparkEmrServerlessRuntimeProps}
     */
    constructor(scope: Construct, id: string, props: SparkEmrServerlessRuntimeProps);
    /**
      * A method which will grant an IAM Role the right to start and monitor a job.
      * The method will also attach an iam:PassRole permission to limited to the IAM Job Execution roles passed.
      * The excution role will be able to submit job to the EMR Serverless application created by the construct.
      *
      * @param startJobRole the role that will call the start job api and which need to have the iam:PassRole permission
      * @param executionRoleArn the role use by EMR Serverless to access resources during the job execution
      */
    grantStartExecution(startJobRole: IRole, executionRoleArn: string): void;
}
